@@ -201,7 +201,7 @@ show_sig_bootstrap_error <- function(bt_result, sample = NULL,
                                      agg_fun = c("mean", "median"),
                                      highlight = "auto", highlight_size = 4,
                                      palette = "aaas", title = NULL,
-                                     xlab = FALSE, ylab = "Reconstruction error (F2 norm)", width = 0.3,
+                                     xlab = FALSE, ylab = "Reconstruction error (L2 norm)", width = 0.3,
                                      dodge_width = 0.8, outlier.shape = NA,
                                      add = "jitter", add.params = list(alpha = 0.3),
                                      legend = "none",
